<?php

require_once '../../../../wp-load.php';
require_once 'chinadivision-common-function.php';

$act = $_POST['act'] ?? '';
switch ($act) {
    case 'auto_register_webhook':
        cd_auto_register_webhooks();
        break;
    case 'check_is_register':
        cd_check_register_webhooks();
        break;
    default:
        cd_setting_save();
        break;
}

function cd_check_register_webhooks()
{
    $isReg = false;
    $webhooks = (new CD_WC_Rest_Api())->getWebhooks(['search' => 'chinadivision']);
    if (isset($webhooks['code'])) {
        cd_api_response_failed('get webhooks failed: ' . $webhooks['message']);
    }
    $registerWebhook = [];
    foreach ($webhooks as $webhook) {
        if (stripos($webhook['delivery_url'], 'chinadivision-woocommerce') !== false
            && $webhook['status'] == 'active'
        ) {
            $registerWebhook[$webhook['topic']] = $webhook;
        }
    }
    if (count($registerWebhook) >= 2) {
        $isReg = true;
    }

    cd_api_response_success(['is_register' => $isReg]);
}

function cd_auto_register_webhooks()
{
    $webhooks = (new CD_WC_Rest_Api())->getWebhooks(['search' => 'chinadivision']);
    if (isset($webhooks['code'])) {
        cd_api_response_failed('get webhooks failed: ' . $webhooks['message']);
    }
    $batchData = [];
    $registerWebhook = [];
    foreach ($webhooks as $webhook) {
        if (stripos($webhook['delivery_url'], 'chinadivision-woocommerce') !== false) {
            $registerWebhook[$webhook['topic']] = $webhook;
            if ($webhook['status'] != 'active') {
                $batchData['update'][] = [
                    'id' => $webhook['id'],
                    'status' => 'active',
                ];
            }
        }
    }
    if (empty($registerWebhook['order.created'])) {
        $batchData['create'][] = [
            'name' => 'chinadivision woocommerce plugins order.created callback',
            'topic' => 'order.created',
            'delivery_url' => cd_get_domain() . '/wp-content/plugins/chinadivision-woocommerce/chinadivision/chinadivision-order-callback.php',
        ];
        $batchData['create'][] = [
            'name' => 'chinadivision woocommerce plugins order.updated callback',
            'topic' => 'order.updated',
            'delivery_url' => cd_get_domain() . '/wp-content/plugins/chinadivision-woocommerce/chinadivision/chinadivision-order-callback.php',
        ];
    }
    if (!empty($batchData)) {
        $ret = (new CD_WC_Rest_Api())->batchWebhooks($batchData);
        if (isset($ret['code'])) {
            cd_trace_log('register webhooks failed: ' . $ret['message'] . "\nwebhooks:" . json_encode($batchData, JSON_UNESCAPED_UNICODE));
            cd_api_response_failed('register webhooks failed: ' . $ret['message']);
        }
    }
    cd_api_response_success();
}

function cd_setting_save()
{
    if (empty($_POST['apikey'])) {
        cd_api_response_failed('apikey can not be empty');
    }
    if (empty($_POST['prefix'])) {
        cd_api_response_failed('prefix can not be empty');
    }
    if (empty($_POST['consumer_key'])) {
        cd_api_response_failed('consumer key can not be empty');
    }
    if (empty($_POST['consumer_secret'])) {
        cd_api_response_failed('consumer secret can not be empty');
    }
    $apikey = trim($_POST['apikey']);
    $prefix = trim($_POST['prefix']);
    $consumerKey = trim($_POST['consumer_key']);
    $consumerSecret = trim($_POST['consumer_secret']);
    $debugLog = intval($_POST['debug_log']);

    $domain = cd_get_domain();
    if (!empty($_POST['domain'])) {
        $domain = trim($_POST['domain']);
    }

    $file = cd_get_plugin_main_path() . '/chinadivision/chinadivision-config.php';
    cd_edit_constant($file, 'CHINADIVISION_API_KEY', $apikey);
    cd_edit_constant($file, 'CHINADIVISION_PREFIX', $prefix);
    cd_edit_constant($file, 'CD_CONSUMER_KEY', $consumerKey);
    cd_edit_constant($file, 'CD_CONSUMER_SECRET', $consumerSecret);
    cd_edit_constant($file, 'CD_DEBUG_INFO', $debugLog);

    if (empty($debugLog)) {
        $file = cd_get_plugin_main_path() . '/chinadivision-trace.log';
        if (file_exists($file)) {
            unlink($file);
        }
    }

    cd_http(CD_UPDATE_SETTING_URL, 'POST', http_build_query(['domain' => $domain]), ['apikey:' . $apikey]);

    cd_api_response_success();
}
